@@ -1,7 +1,7 @@
 /*--------------------------------------------------------------------
- *	$Id: psrose.c 18134 2017-05-05 08:34:43Z pwessel $
+ *	$Id: psrose.c 20119 2018-05-09 22:22:09Z pwessel $
  *
- *	Copyright (c) 1991-2017 by P. Wessel, W. H. F. Smith, R. Scharroo, J. Luis and F. Wobbe
+ *	Copyright (c) 1991-2018 by P. Wessel, W. H. F. Smith, R. Scharroo, J. Luis and F. Wobbe
  *	See LICENSE.TXT file for copying and redistribution conditions.
  *
  *	This program is free software; you can redistribute it and/or modify
@@ -787,7 +787,7 @@ int GMT_psrose (void *V_API, int mode, void *args) {
 		}
 	}
 
-	if (sector_plot && !Ctrl->A.rose && Ctrl->G.fill.rgb[0] >= 0) {	/* Draw pie slices for sector plot if fill is requested */
+	if (sector_plot && !Ctrl->A.rose && Ctrl->G.active) {	/* Draw pie slices for sector plot if fill is requested */
 
 		gmt_setfill (GMT, &(Ctrl->G.fill), false);
 		for (bin = 0; bin < n_bins; bin++) {
